% Get super-resolution system matrix and their Jacobian w.r.t. the motion
% parameters.
function [W, J] = getSystemMatrixAndJacobian(x, optStruct, motionParams, magFactor)

    D = optStruct.D;
    H = optStruct.H;
    numFrames = optStruct.numFrames;
    M = optStruct.Size(1);
    N = optStruct.Size(2);
    
    % Geometric motion operator. 
    [B, C, S] = subpixelWarp(x, motionParams, optStruct); 
    
    % Compute system matrix and Jacobian w.r.t. the motion parameters.
    W = D*H;
    for k = 2 : numFrames
        
        % Calculate system matrix for the k-th frame and assemble the
        % overall system matrix.
        W = cat(1, W, sparse(D*H*S{k})); 
        
        % Calculate Jacobian for the k-th frame and assemble the overall
        % Jacobian.
        if k == 2
            J = sparse(D*H*B{k}*C);
        else
            J = cat(1, J, sparse(D*H*B{k}*C)); 
        end
    end
    J = createDiagonal(J, M/magFactor * N/magFactor);